# @prefecthq/prefab-ui-docs

Shadow DOM preview renderer for [Prefab](https://prefab.prefect.io) documentation.

This package contains the embed build used by Mintlify doc previews. It is published automatically alongside the main `@prefecthq/prefab-ui` package and should not be installed directly.

If you're building with Prefab, see the [main package](https://www.npmjs.com/package/@prefecthq/prefab-ui).
